# This file was auto-generated by Fern from our API Definition.

import typing

Topics = typing.Union[
    typing.Literal[
        "basic",
        "environmental",
        "social",
        "cybersecurity",
        "disruption",
        "criminal",
        "reputational",
        "financial",
        "regulatory",
        "legal",
        "misconduct",
        "terrorism",
        "sanctions",
        "all",
    ],
    typing.Any,
]
