# This file was auto-generated by Fern from our API Definition.

import typing

NameContext = typing.Union[
    typing.Literal["alias", "family", "given", "machine_translation", "primary", "trade_name", "transliteration"],
    typing.Any,
]
