# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...shared_types.types.relationship_info import RelationshipInfo
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TraversalRelationshipData(UniversalBaseModel):
    values: typing.List[RelationshipInfo]
    former: typing.Optional[bool] = None
    start_date: typing.Optional[str] = None
    last_observed: typing.Optional[str] = None
    end_date: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
